@@ -6,13 +6,13 @@ import Stackctl.Prelude
 
 import Amazonka.EC2.DescribeAvailabilityZones
 import Amazonka.EC2.Types (AvailabilityZone (..))
-import Stackctl.AWS.Core
+import Stackctl.AWS.Core as AWS
 
 awsEc2DescribeFirstAvailabilityZoneRegionName
-  :: (MonadResource m, MonadReader env m, HasAwsEnv env) => m Region
+  :: (MonadIO m, MonadAWS m) => m Region
 awsEc2DescribeFirstAvailabilityZoneRegionName = do
   let req = newDescribeAvailabilityZones
-  awsSimple req $ \resp -> do
+  AWS.simple req $ \resp -> do
     azs <- resp ^. describeAvailabilityZonesResponse_availabilityZones
     az <- listToMaybe azs
     rn <- regionName az
